@@ -1,3 +1,5 @@
+import colored
+from colored import stylize
 import json
 import pkg_resources
 from pyraider.utils import export_to_csv, export_to_json, show_vulnerablities, \
@@ -9,6 +11,8 @@ def read_from_env():
     """
         Collect requirments from env and scan and show reports
     """
+    print(stylize('Started Scanning .....', colored.fg("green")))
+    print('\n')
     data = scan_vulnerabilities()
     dists = [d for d in pkg_resources.working_set]
     for pkg in dists:
@@ -62,6 +66,8 @@ def read_from_file(to_scan_file, export_format=None, export_file_path=None, is_p
     """
         Read requirents from requirements.txt file and also we can generate a JSON and CSV report.
     """
+    print(stylize('Started Scanning .....', colored.fg("green")))
+    print('\n')
     data_dict = []
     secure_data_dict = []
     data = scan_vulnerabilities()
@@ -70,51 +76,44 @@ def read_from_file(to_scan_file, export_format=None, export_file_path=None, is_p
             line = json.loads(fp.read())
             for k, v in line['default'].items():
                 req_name = k.lower()
-                req_version = v['version'].split("==")[1]
-                scanned_data = scanned_vulnerable_data(
+                package_version = v['version'].split("==")
+                req_version = package_version[1]
+                pyenv_scanned_data = scanned_vulnerable_data(
                     data, req_name, req_version)
-                if scanned_data:
-                    show_vulnerablities(scanned_data)
+                if bool(pyenv_scanned_data):
+                    show_vulnerablities(pyenv_scanned_data)
                     if export_format == 'json':
-                        data_dict.append(scanned_data)
+                        data_dict.append(pyenv_scanned_data)
                     elif export_format == 'csv':
-                        data_dict.append(scanned_data)
-                else:
-                    data = {}
-                    data[req_name] = {}
-                    data[req_name]['current_version'] = req_version
-                    secure_data_dict.append(data)
+                        data_dict.append(pyenv_scanned_data)
+            show_secure_packages(secure_data_dict)
     else:
         with open(to_scan_file) as fp:
             line = fp.readline()
             cnt = 1
             while line:
-                req = line.strip().split('==')
-                if len(req) == 2:
-                    req_name = req[0].lower()
-                    req_version = req[1]
-                    scanned_data = scanned_vulnerable_data(
-                        data, req_name, req_version)
-                    if scanned_data:
-                        show_vulnerablities(scanned_data)
+                package = line.strip()
+                txt_req = package.split('==')
+                if len(txt_req) == 2:
+                    txt_req_name = txt_req[0].lower()
+                    txt_req_version = txt_req[1]
+                    txt_scanned_data = scanned_vulnerable_data(
+                        data, txt_req_name, txt_req_version)
+                    if bool(txt_scanned_data):
+                        show_vulnerablities(txt_scanned_data)
                         if export_format == 'json':
-                            data_dict.append(scanned_data)
+                            data_dict.append(txt_scanned_data)
                         elif export_format == 'csv':
-                            data_dict.append(scanned_data)
-                    else:
-                        data = {}
-                        data[req_name] = {}
-                        data[req_name]['current_version'] = req_version
-                        secure_data_dict.append(data)
+                            data_dict.append(txt_scanned_data)
                 line = fp.readline()
                 cnt += 1
         show_secure_packages(secure_data_dict)
     if export_format == 'json':
-        report_header = {'pyraider': '0.2'}
+        report_header = {'pyraider': '0.4.6'}
         data_dict.append(report_header)
         export_to_json(data_dict, export_file_path)
     elif export_format == 'csv':
-        report_header = {'pyraider': '0.2'}
+        report_header = {'pyraider': '0.4.6'}
         data_dict.append(report_header)
         export_to_csv(data_dict, export_file_path)
 
